@@ -1,6 +1,6 @@
 /*
- *  Copyright (C) 2002-2004 Marco Pesenti Gritti
- *  Copyright (C) 2004 Christian Persch
+ *  Copyright © 2002-2004 Marco Pesenti Gritti
+ *  Copyright © 2004 Christian Persch
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -14,9 +14,9 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- *  $Id: egg-toolbars-model.c,v 1.42 2006/02/21 13:44:15 paharvey Exp $
+ *  $Id: egg-toolbars-model.c 6952 2007-03-11 19:42:02Z chpe $
  */
 
 #include "config.h"
@@ -75,7 +75,7 @@ egg_toolbars_model_get_type (void)
 
   if (G_UNLIKELY (type == 0))
     {
-      static const GTypeInfo our_info = {
+      const GTypeInfo our_info = {
 	sizeof (EggToolbarsModelClass),
 	NULL,			/* base_init */
 	NULL,			/* base_finalize */
